Index — primer-designer 0.0.1 documentation

# Index

D | I | P | R

## D

design_primers() (primer_designer.designer.PrimerDesigner method) (primer_designer.PrimerDesigner method)

## I

insert_taxon_in_new_fasta_file() (primer_designer.designer.PrimerDesigner method) (primer_designer.PrimerDesigner method) | is_fasta() (in module primer_designer.utils)

## P

primer_designer (module) primer_designer.designer (module) primer_designer.utils (module) | PrimerDesigner (class in primer_designer) (class in primer_designer.designer) process_response() (primer_designer.designer.PrimerDesigner method) (primer_designer.PrimerDesigner method)

## R

request_primers() (primer_designer.designer.PrimerDesigner method) (primer_designer.PrimerDesigner method)